gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[GNUnet-SVN] r20512 - in gnunet/src: include util


From: gnunet
Subject: [GNUnet-SVN] r20512 - in gnunet/src: include util
Date: Thu, 15 Mar 2012 11:17:44 +0100

Author: wachs
Date: 2012-03-15 11:17:44 +0100 (Thu, 15 Mar 2012)
New Revision: 20512

Modified:
   gnunet/src/include/gnunet_program_lib.h
   gnunet/src/util/program.c
Log:
- improve documentation


Modified: gnunet/src/include/gnunet_program_lib.h
===================================================================
--- gnunet/src/include/gnunet_program_lib.h     2012-03-15 10:17:18 UTC (rev 
20511)
+++ gnunet/src/include/gnunet_program_lib.h     2012-03-15 10:17:44 UTC (rev 
20512)
@@ -64,7 +64,7 @@
  * @param options command line options
  * @param task main function to run
  * @param task_cls closure for task
- * @param run_with_schedule GNUNET_YES start the scheduler, GNUNET_NO do not
+ * @param run_without_scheduler GNUNET_NO start the scheduler, GNUNET_YES do 
not
  *        start the scheduler just run the main task
  * @return GNUNET_SYSERR on error, GNUNET_OK on success
  */
@@ -73,7 +73,7 @@
                     const char *binaryHelp,
                     const struct GNUNET_GETOPT_CommandLineOption *options,
                     GNUNET_PROGRAM_Main task, void *task_cls,
-                    int run_with_schedule);
+                    int run_without_scheduler);
 
 /**
  * Run a standard GNUnet command startup sequence (initialize loggers

Modified: gnunet/src/util/program.c
===================================================================
--- gnunet/src/util/program.c   2012-03-15 10:17:18 UTC (rev 20511)
+++ gnunet/src/util/program.c   2012-03-15 10:17:44 UTC (rev 20512)
@@ -125,7 +125,7 @@
  * @param options command line options
  * @param task main function to run
  * @param task_cls closure for task
  * @param run_with_schedule GNUNET_NO start the scheduler, GNUNET_YES do not
not
  *        start the scheduler just run the main task
  * @return GNUNET_SYSERR on error, GNUNET_OK on success
  */
@@ -134,7 +134,7 @@
                     const char *binaryHelp,
                     const struct GNUNET_GETOPT_CommandLineOption *options,
                     GNUNET_PROGRAM_Main task, void *task_cls,
-                    int run_with_schedule)
+                    int run_without_scheduler)
 {
   struct CommandContext cc;
   char *path;
@@ -250,7 +250,7 @@
   }
   /* run */
   cc.args = &argv[ret];
-  if (GNUNET_NO == run_with_schedule)
+  if (GNUNET_NO == run_without_scheduler)
   {
           GNUNET_SCHEDULER_run (&program_main, &cc);
   }
@@ -125,7 +125,7 @@
  * @param task main function to run
  * @param task_cls closure for task
- * @param run_with_schedule GNUNET_NO start the scheduler, GNUNET_YES do not
+ * @param run_without_scheduler GNUNET_NO start the scheduler, GNUNET_YES do 
not
  *        start the scheduler just run the main task




reply via email to

[Prev in Thread] Current Thread [Next in Thread]